# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/gov/v1beta1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from cosmos.gov.v1beta1 import gov_pb2 as cosmos_dot_gov_dot_v1beta1_dot_gov__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x63osmos/gov/v1beta1/tx.proto\x12\x12\x63osmos.gov.v1beta1\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x1c\x63osmos/gov/v1beta1/gov.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x11\x61mino/amino.proto\"\xb1\x02\n\x11MsgSubmitProposal\x12\x45\n\x07\x63ontent\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyB\x1e\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\x12i\n\x0finitial_deposit\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB5\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12*\n\x08proposer\x18\x03 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString:>\x82\xe7\xb0*\x08proposer\x8a\xe7\xb0*\x1c\x63osmos-sdk/MsgSubmitProposal\xe8\xa0\x1f\x00\x98\xa0\x1f\x00\x80\xdc \x00\x88\xa0\x1f\x00\"F\n\x19MsgSubmitProposalResponse\x12)\n\x0bproposal_id\x18\x01 \x01(\x04\x42\x14\xea\xde\x1f\x0bproposal_id\xa8\xe7\xb0*\x01\"\xaa\x01\n\x07MsgVote\x12\x13\n\x0bproposal_id\x18\x01 \x01(\x04\x12\'\n\x05voter\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12.\n\x06option\x18\x03 \x01(\x0e\x32\x1e.cosmos.gov.v1beta1.VoteOption:1\x82\xe7\xb0*\x05voter\x8a\xe7\xb0*\x12\x63osmos-sdk/MsgVote\xe8\xa0\x1f\x00\x98\xa0\x1f\x00\x80\xdc \x00\x88\xa0\x1f\x00\"\x11\n\x0fMsgVoteResponse\"\xe4\x01\n\x0fMsgVoteWeighted\x12)\n\x0bproposal_id\x18\x01 \x01(\x04\x42\x14\xea\xde\x1f\x0bproposal_id\xa8\xe7\xb0*\x01\x12\'\n\x05voter\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x42\n\x07options\x18\x03 \x03(\x0b\x32&.cosmos.gov.v1beta1.WeightedVoteOptionB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01:9\x82\xe7\xb0*\x05voter\x8a\xe7\xb0*\x1a\x63osmos-sdk/MsgVoteWeighted\xe8\xa0\x1f\x00\x98\xa0\x1f\x00\x80\xdc \x00\x88\xa0\x1f\x00\"\x19\n\x17MsgVoteWeightedResponse\"\x80\x02\n\nMsgDeposit\x12)\n\x0bproposal_id\x18\x01 \x01(\x04\x42\x14\xea\xde\x1f\x0bproposal_id\xa8\xe7\xb0*\x01\x12+\n\tdepositor\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12`\n\x06\x61mount\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB5\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins:8\x82\xe7\xb0*\tdepositor\x8a\xe7\xb0*\x15\x63osmos-sdk/MsgDeposit\xe8\xa0\x1f\x00\x98\xa0\x1f\x00\x80\xdc \x00\x88\xa0\x1f\x00\"\x14\n\x12MsgDepositResponse2\xf3\x02\n\x03Msg\x12\x66\n\x0eSubmitProposal\x12%.cosmos.gov.v1beta1.MsgSubmitProposal\x1a-.cosmos.gov.v1beta1.MsgSubmitProposalResponse\x12H\n\x04Vote\x12\x1b.cosmos.gov.v1beta1.MsgVote\x1a#.cosmos.gov.v1beta1.MsgVoteResponse\x12`\n\x0cVoteWeighted\x12#.cosmos.gov.v1beta1.MsgVoteWeighted\x1a+.cosmos.gov.v1beta1.MsgVoteWeightedResponse\x12Q\n\x07\x44\x65posit\x12\x1e.cosmos.gov.v1beta1.MsgDeposit\x1a&.cosmos.gov.v1beta1.MsgDepositResponse\x1a\x05\x80\xe7\xb0*\x01\x42\x32Z0github.com/cosmos/cosmos-sdk/x/gov/types/v1beta1b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.gov.v1beta1.tx_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z0github.com/cosmos/cosmos-sdk/x/gov/types/v1beta1'
  _MSGSUBMITPROPOSAL.fields_by_name['content']._options = None
  _MSGSUBMITPROPOSAL.fields_by_name['content']._serialized_options = b'\312\264-\032cosmos.gov.v1beta1.Content'
  _MSGSUBMITPROPOSAL.fields_by_name['initial_deposit']._options = None
  _MSGSUBMITPROPOSAL.fields_by_name['initial_deposit']._serialized_options = b'\310\336\037\000\250\347\260*\001\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _MSGSUBMITPROPOSAL.fields_by_name['proposer']._options = None
  _MSGSUBMITPROPOSAL.fields_by_name['proposer']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGSUBMITPROPOSAL._options = None
  _MSGSUBMITPROPOSAL._serialized_options = b'\202\347\260*\010proposer\212\347\260*\034cosmos-sdk/MsgSubmitProposal\350\240\037\000\230\240\037\000\200\334 \000\210\240\037\000'
  _MSGSUBMITPROPOSALRESPONSE.fields_by_name['proposal_id']._options = None
  _MSGSUBMITPROPOSALRESPONSE.fields_by_name['proposal_id']._serialized_options = b'\352\336\037\013proposal_id\250\347\260*\001'
  _MSGVOTE.fields_by_name['voter']._options = None
  _MSGVOTE.fields_by_name['voter']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGVOTE._options = None
  _MSGVOTE._serialized_options = b'\202\347\260*\005voter\212\347\260*\022cosmos-sdk/MsgVote\350\240\037\000\230\240\037\000\200\334 \000\210\240\037\000'
  _MSGVOTEWEIGHTED.fields_by_name['proposal_id']._options = None
  _MSGVOTEWEIGHTED.fields_by_name['proposal_id']._serialized_options = b'\352\336\037\013proposal_id\250\347\260*\001'
  _MSGVOTEWEIGHTED.fields_by_name['voter']._options = None
  _MSGVOTEWEIGHTED.fields_by_name['voter']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGVOTEWEIGHTED.fields_by_name['options']._options = None
  _MSGVOTEWEIGHTED.fields_by_name['options']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _MSGVOTEWEIGHTED._options = None
  _MSGVOTEWEIGHTED._serialized_options = b'\202\347\260*\005voter\212\347\260*\032cosmos-sdk/MsgVoteWeighted\350\240\037\000\230\240\037\000\200\334 \000\210\240\037\000'
  _MSGDEPOSIT.fields_by_name['proposal_id']._options = None
  _MSGDEPOSIT.fields_by_name['proposal_id']._serialized_options = b'\352\336\037\013proposal_id\250\347\260*\001'
  _MSGDEPOSIT.fields_by_name['depositor']._options = None
  _MSGDEPOSIT.fields_by_name['depositor']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGDEPOSIT.fields_by_name['amount']._options = None
  _MSGDEPOSIT.fields_by_name['amount']._serialized_options = b'\310\336\037\000\250\347\260*\001\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _MSGDEPOSIT._options = None
  _MSGDEPOSIT._serialized_options = b'\202\347\260*\tdepositor\212\347\260*\025cosmos-sdk/MsgDeposit\350\240\037\000\230\240\037\000\200\334 \000\210\240\037\000'
  _MSG._options = None
  _MSG._serialized_options = b'\200\347\260*\001'
  _MSGSUBMITPROPOSAL._serialized_start=234
  _MSGSUBMITPROPOSAL._serialized_end=539
  _MSGSUBMITPROPOSALRESPONSE._serialized_start=541
  _MSGSUBMITPROPOSALRESPONSE._serialized_end=611
  _MSGVOTE._serialized_start=614
  _MSGVOTE._serialized_end=784
  _MSGVOTERESPONSE._serialized_start=786
  _MSGVOTERESPONSE._serialized_end=803
  _MSGVOTEWEIGHTED._serialized_start=806
  _MSGVOTEWEIGHTED._serialized_end=1034
  _MSGVOTEWEIGHTEDRESPONSE._serialized_start=1036
  _MSGVOTEWEIGHTEDRESPONSE._serialized_end=1061
  _MSGDEPOSIT._serialized_start=1064
  _MSGDEPOSIT._serialized_end=1320
  _MSGDEPOSITRESPONSE._serialized_start=1322
  _MSGDEPOSITRESPONSE._serialized_end=1342
  _MSG._serialized_start=1345
  _MSG._serialized_end=1716
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/applications/interchain_accounts/genesis/v1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ibc.applications.interchain_accounts.controller.v1 import controller_pb2 as ibc_dot_applications_dot_interchain__accounts_dot_controller_dot_v1_dot_controller__pb2
from ibc.applications.interchain_accounts.host.v1 import host_pb2 as ibc_dot_applications_dot_interchain__accounts_dot_host_dot_v1_dot_host__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=ibc/applications/interchain_accounts/genesis/v1/genesis.proto\x12/ibc.applications.interchain_accounts.genesis.v1\x1a\x14gogoproto/gogo.proto\x1a\x43ibc/applications/interchain_accounts/controller/v1/controller.proto\x1a\x37ibc/applications/interchain_accounts/host/v1/host.proto\"\xe4\x01\n\x0cGenesisState\x12o\n\x18\x63ontroller_genesis_state\x18\x01 \x01(\x0b\x32G.ibc.applications.interchain_accounts.genesis.v1.ControllerGenesisStateB\x04\xc8\xde\x1f\x00\x12\x63\n\x12host_genesis_state\x18\x02 \x01(\x0b\x32\x41.ibc.applications.interchain_accounts.genesis.v1.HostGenesisStateB\x04\xc8\xde\x1f\x00\"\xc9\x02\n\x16\x43ontrollerGenesisState\x12]\n\x0f\x61\x63tive_channels\x18\x01 \x03(\x0b\x32>.ibc.applications.interchain_accounts.genesis.v1.ActiveChannelB\x04\xc8\xde\x1f\x00\x12o\n\x13interchain_accounts\x18\x02 \x03(\x0b\x32L.ibc.applications.interchain_accounts.genesis.v1.RegisteredInterchainAccountB\x04\xc8\xde\x1f\x00\x12\r\n\x05ports\x18\x03 \x03(\t\x12P\n\x06params\x18\x04 \x01(\x0b\x32:.ibc.applications.interchain_accounts.controller.v1.ParamsB\x04\xc8\xde\x1f\x00\"\xbc\x02\n\x10HostGenesisState\x12]\n\x0f\x61\x63tive_channels\x18\x01 \x03(\x0b\x32>.ibc.applications.interchain_accounts.genesis.v1.ActiveChannelB\x04\xc8\xde\x1f\x00\x12o\n\x13interchain_accounts\x18\x02 \x03(\x0b\x32L.ibc.applications.interchain_accounts.genesis.v1.RegisteredInterchainAccountB\x04\xc8\xde\x1f\x00\x12\x0c\n\x04port\x18\x03 \x01(\t\x12J\n\x06params\x18\x04 \x01(\x0b\x32\x34.ibc.applications.interchain_accounts.host.v1.ParamsB\x04\xc8\xde\x1f\x00\"j\n\rActiveChannel\x12\x15\n\rconnection_id\x18\x01 \x01(\t\x12\x0f\n\x07port_id\x18\x02 \x01(\t\x12\x12\n\nchannel_id\x18\x03 \x01(\t\x12\x1d\n\x15is_middleware_enabled\x18\x04 \x01(\x08\"^\n\x1bRegisteredInterchainAccount\x12\x15\n\rconnection_id\x18\x01 \x01(\t\x12\x0f\n\x07port_id\x18\x02 \x01(\t\x12\x17\n\x0f\x61\x63\x63ount_address\x18\x03 \x01(\tBOZMgithub.com/cosmos/ibc-go/v7/modules/apps/27-interchain-accounts/genesis/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.interchain_accounts.genesis.v1.genesis_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZMgithub.com/cosmos/ibc-go/v7/modules/apps/27-interchain-accounts/genesis/types'
  _GENESISSTATE.fields_by_name['controller_genesis_state']._options = None
  _GENESISSTATE.fields_by_name['controller_genesis_state']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE.fields_by_name['host_genesis_state']._options = None
  _GENESISSTATE.fields_by_name['host_genesis_state']._serialized_options = b'\310\336\037\000'
  _CONTROLLERGENESISSTATE.fields_by_name['active_channels']._options = None
  _CONTROLLERGENESISSTATE.fields_by_name['active_channels']._serialized_options = b'\310\336\037\000'
  _CONTROLLERGENESISSTATE.fields_by_name['interchain_accounts']._options = None
  _CONTROLLERGENESISSTATE.fields_by_name['interchain_accounts']._serialized_options = b'\310\336\037\000'
  _CONTROLLERGENESISSTATE.fields_by_name['params']._options = None
  _CONTROLLERGENESISSTATE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _HOSTGENESISSTATE.fields_by_name['active_channels']._options = None
  _HOSTGENESISSTATE.fields_by_name['active_channels']._serialized_options = b'\310\336\037\000'
  _HOSTGENESISSTATE.fields_by_name['interchain_accounts']._options = None
  _HOSTGENESISSTATE.fields_by_name['interchain_accounts']._serialized_options = b'\310\336\037\000'
  _HOSTGENESISSTATE.fields_by_name['params']._options = None
  _HOSTGENESISSTATE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE._serialized_start=263
  _GENESISSTATE._serialized_end=491
  _CONTROLLERGENESISSTATE._serialized_start=494
  _CONTROLLERGENESISSTATE._serialized_end=823
  _HOSTGENESISSTATE._serialized_start=826
  _HOSTGENESISSTATE._serialized_end=1142
  _ACTIVECHANNEL._serialized_start=1144
  _ACTIVECHANNEL._serialized_end=1250
  _REGISTEREDINTERCHAINACCOUNT._serialized_start=1252
  _REGISTEREDINTERCHAINACCOUNT._serialized_end=1346
# @@protoc_insertion_point(module_scope)



import logging

import pytest
from pyinjective.constant import Network

from pyinjective.async_client import AsyncClient


class TestAsyncClient:

    def test_instance_creation_logs_session_cookie_load_info(self, caplog):
        caplog.set_level(logging.INFO)

        AsyncClient(
            network=Network.local(),
            insecure=False,
        )

        expected_log_message_prefix = "chain session cookie loaded from disk: "
        found_log = next(
            (record for record in caplog.record_tuples if record[2].startswith(expected_log_message_prefix)),
            None,
        )
        assert(found_log is not None)
        assert(found_log[0] == "pyinjective.async_client.AsyncClient")
        assert(found_log[1] == logging.INFO)


    @pytest.mark.asyncio
    async def test_sync_timeout_height_logs_exception(self, caplog):
        client = AsyncClient(
            network=Network.local(),
            insecure=False,
        )

        with caplog.at_level(logging.DEBUG):
            await client.sync_timeout_height()

        expected_log_message_prefix = "error while fetching latest block, setting timeout height to 0: "
        found_log = next(
            (record for record in caplog.record_tuples if record[2].startswith(expected_log_message_prefix)),
            None,
        )
        assert (found_log is not None)
        assert (found_log[0] == "pyinjective.async_client.AsyncClient")
        assert (found_log[1] == logging.DEBUG)

    def test_set_cookie_logs_chain_session_cookie_saved(self, caplog):
        caplog.set_level(logging.INFO)

        client = AsyncClient(
            network=Network.local(),
            insecure=False,
        )

        client.set_cookie(metadata=[("set-cookie", "test-value")], type="chain")

        expected_log_message_prefix = "chain session cookie saved to disk"
        found_log = next(
            (record for record in caplog.record_tuples if record[2].startswith(expected_log_message_prefix)),
            None,
        )
        assert (found_log is not None)
        assert (found_log[0] == "pyinjective.async_client.AsyncClient")
        assert (found_log[1] == logging.INFO)

    @pytest.mark.asyncio
    async def test_get_account_logs_exception(self, caplog):
        client = AsyncClient(
            network=Network.local(),
            insecure=False,
        )

        with caplog.at_level(logging.DEBUG):
            await client.get_account(address="")

        expected_log_message_prefix = "error while fetching sequence and number "
        found_log = next(
            (record for record in caplog.record_tuples if record[2].startswith(expected_log_message_prefix)),
            None,
        )
        assert (found_log is not None)
        assert (found_log[0] == "pyinjective.async_client.AsyncClient")
        assert (found_log[1] == logging.DEBUG)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/applications/fee/v1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ibc.applications.fee.v1 import fee_pb2 as ibc_dot_applications_dot_fee_dot_v1_dot_fee__pb2
from ibc.core.channel.v1 import channel_pb2 as ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2
from cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n ibc/applications/fee/v1/tx.proto\x12\x17ibc.applications.fee.v1\x1a\x14gogoproto/gogo.proto\x1a!ibc/applications/fee/v1/fee.proto\x1a!ibc/core/channel/v1/channel.proto\x1a\x17\x63osmos/msg/v1/msg.proto\"m\n\x10MsgRegisterPayee\x12\x0f\n\x07port_id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\x12\x0f\n\x07relayer\x18\x03 \x01(\t\x12\r\n\x05payee\x18\x04 \x01(\t:\x14\x82\xe7\xb0*\x07relayer\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1a\n\x18MsgRegisterPayeeResponse\"\x86\x01\n\x1cMsgRegisterCounterpartyPayee\x12\x0f\n\x07port_id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\x12\x0f\n\x07relayer\x18\x03 \x01(\t\x12\x1a\n\x12\x63ounterparty_payee\x18\x04 \x01(\t:\x14\x82\xe7\xb0*\x07relayer\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"&\n$MsgRegisterCounterpartyPayeeResponse\"\xac\x01\n\x0fMsgPayPacketFee\x12/\n\x03\x66\x65\x65\x18\x01 \x01(\x0b\x32\x1c.ibc.applications.fee.v1.FeeB\x04\xc8\xde\x1f\x00\x12\x16\n\x0esource_port_id\x18\x02 \x01(\t\x12\x19\n\x11source_channel_id\x18\x03 \x01(\t\x12\x0e\n\x06signer\x18\x04 \x01(\t\x12\x10\n\x08relayers\x18\x05 \x03(\t:\x13\x82\xe7\xb0*\x06signer\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x19\n\x17MsgPayPacketFeeResponse\"\xb3\x01\n\x14MsgPayPacketFeeAsync\x12\x36\n\tpacket_id\x18\x01 \x01(\x0b\x32\x1d.ibc.core.channel.v1.PacketIdB\x04\xc8\xde\x1f\x00\x12<\n\npacket_fee\x18\x02 \x01(\x0b\x32\".ibc.applications.fee.v1.PacketFeeB\x04\xc8\xde\x1f\x00:%\x82\xe7\xb0*\x18packet_fee.refundaddress\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1e\n\x1cMsgPayPacketFeeAsyncResponse2\xf6\x03\n\x03Msg\x12m\n\rRegisterPayee\x12).ibc.applications.fee.v1.MsgRegisterPayee\x1a\x31.ibc.applications.fee.v1.MsgRegisterPayeeResponse\x12\x91\x01\n\x19RegisterCounterpartyPayee\x12\x35.ibc.applications.fee.v1.MsgRegisterCounterpartyPayee\x1a=.ibc.applications.fee.v1.MsgRegisterCounterpartyPayeeResponse\x12j\n\x0cPayPacketFee\x12(.ibc.applications.fee.v1.MsgPayPacketFee\x1a\x30.ibc.applications.fee.v1.MsgPayPacketFeeResponse\x12y\n\x11PayPacketFeeAsync\x12-.ibc.applications.fee.v1.MsgPayPacketFeeAsync\x1a\x35.ibc.applications.fee.v1.MsgPayPacketFeeAsyncResponse\x1a\x05\x80\xe7\xb0*\x01\x42\x37Z5github.com/cosmos/ibc-go/v7/modules/apps/29-fee/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.fee.v1.tx_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/cosmos/ibc-go/v7/modules/apps/29-fee/types'
  _MSGREGISTERPAYEE._options = None
  _MSGREGISTERPAYEE._serialized_options = b'\202\347\260*\007relayer\350\240\037\000\210\240\037\000'
  _MSGREGISTERCOUNTERPARTYPAYEE._options = None
  _MSGREGISTERCOUNTERPARTYPAYEE._serialized_options = b'\202\347\260*\007relayer\350\240\037\000\210\240\037\000'
  _MSGPAYPACKETFEE.fields_by_name['fee']._options = None
  _MSGPAYPACKETFEE.fields_by_name['fee']._serialized_options = b'\310\336\037\000'
  _MSGPAYPACKETFEE._options = None
  _MSGPAYPACKETFEE._serialized_options = b'\202\347\260*\006signer\350\240\037\000\210\240\037\000'
  _MSGPAYPACKETFEEASYNC.fields_by_name['packet_id']._options = None
  _MSGPAYPACKETFEEASYNC.fields_by_name['packet_id']._serialized_options = b'\310\336\037\000'
  _MSGPAYPACKETFEEASYNC.fields_by_name['packet_fee']._options = None
  _MSGPAYPACKETFEEASYNC.fields_by_name['packet_fee']._serialized_options = b'\310\336\037\000'
  _MSGPAYPACKETFEEASYNC._options = None
  _MSGPAYPACKETFEEASYNC._serialized_options = b'\202\347\260*\030packet_fee.refundaddress\350\240\037\000\210\240\037\000'
  _MSG._options = None
  _MSG._serialized_options = b'\200\347\260*\001'
  _MSGREGISTERPAYEE._serialized_start=178
  _MSGREGISTERPAYEE._serialized_end=287
  _MSGREGISTERPAYEERESPONSE._serialized_start=289
  _MSGREGISTERPAYEERESPONSE._serialized_end=315
  _MSGREGISTERCOUNTERPARTYPAYEE._serialized_start=318
  _MSGREGISTERCOUNTERPARTYPAYEE._serialized_end=452
  _MSGREGISTERCOUNTERPARTYPAYEERESPONSE._serialized_start=454
  _MSGREGISTERCOUNTERPARTYPAYEERESPONSE._serialized_end=492
  _MSGPAYPACKETFEE._serialized_start=495
  _MSGPAYPACKETFEE._serialized_end=667
  _MSGPAYPACKETFEERESPONSE._serialized_start=669
  _MSGPAYPACKETFEERESPONSE._serialized_end=694
  _MSGPAYPACKETFEEASYNC._serialized_start=697
  _MSGPAYPACKETFEEASYNC._serialized_end=876
  _MSGPAYPACKETFEEASYNCRESPONSE._serialized_start=878
  _MSGPAYPACKETFEEASYNCRESPONSE._serialized_end=908
  _MSG._serialized_start=911
  _MSG._serialized_end=1413
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/core/connection/v1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ibc.core.connection.v1 import connection_pb2 as ibc_dot_core_dot_connection_dot_v1_dot_connection__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$ibc/core/connection/v1/genesis.proto\x12\x16ibc.core.connection.v1\x1a\x14gogoproto/gogo.proto\x1a\'ibc/core/connection/v1/connection.proto\"\xff\x01\n\x0cGenesisState\x12G\n\x0b\x63onnections\x18\x01 \x03(\x0b\x32,.ibc.core.connection.v1.IdentifiedConnectionB\x04\xc8\xde\x1f\x00\x12N\n\x17\x63lient_connection_paths\x18\x02 \x03(\x0b\x32\'.ibc.core.connection.v1.ConnectionPathsB\x04\xc8\xde\x1f\x00\x12 \n\x18next_connection_sequence\x18\x03 \x01(\x04\x12\x34\n\x06params\x18\x04 \x01(\x0b\x32\x1e.ibc.core.connection.v1.ParamsB\x04\xc8\xde\x1f\x00\x42>Z<github.com/cosmos/ibc-go/v7/modules/core/03-connection/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.core.connection.v1.genesis_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z<github.com/cosmos/ibc-go/v7/modules/core/03-connection/types'
  _GENESISSTATE.fields_by_name['connections']._options = None
  _GENESISSTATE.fields_by_name['connections']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE.fields_by_name['client_connection_paths']._options = None
  _GENESISSTATE.fields_by_name['client_connection_paths']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE.fields_by_name['params']._options = None
  _GENESISSTATE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE._serialized_start=128
  _GENESISSTATE._serialized_end=383
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/applications/fee/v1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ibc.applications.fee.v1 import fee_pb2 as ibc_dot_applications_dot_fee_dot_v1_dot_fee__pb2
from ibc.core.channel.v1 import channel_pb2 as ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%ibc/applications/fee/v1/genesis.proto\x12\x17ibc.applications.fee.v1\x1a\x14gogoproto/gogo.proto\x1a!ibc/applications/fee/v1/fee.proto\x1a!ibc/core/channel/v1/channel.proto\"\xab\x03\n\x0cGenesisState\x12L\n\x0fidentified_fees\x18\x01 \x03(\x0b\x32-.ibc.applications.fee.v1.IdentifiedPacketFeesB\x04\xc8\xde\x1f\x00\x12N\n\x14\x66\x65\x65_enabled_channels\x18\x02 \x03(\x0b\x32*.ibc.applications.fee.v1.FeeEnabledChannelB\x04\xc8\xde\x1f\x00\x12I\n\x11registered_payees\x18\x03 \x03(\x0b\x32(.ibc.applications.fee.v1.RegisteredPayeeB\x04\xc8\xde\x1f\x00\x12\x62\n\x1eregistered_counterparty_payees\x18\x04 \x03(\x0b\x32\x34.ibc.applications.fee.v1.RegisteredCounterpartyPayeeB\x04\xc8\xde\x1f\x00\x12N\n\x10\x66orward_relayers\x18\x05 \x03(\x0b\x32..ibc.applications.fee.v1.ForwardRelayerAddressB\x04\xc8\xde\x1f\x00\"8\n\x11\x46\x65\x65\x45nabledChannel\x12\x0f\n\x07port_id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\"E\n\x0fRegisteredPayee\x12\x12\n\nchannel_id\x18\x01 \x01(\t\x12\x0f\n\x07relayer\x18\x02 \x01(\t\x12\r\n\x05payee\x18\x03 \x01(\t\"^\n\x1bRegisteredCounterpartyPayee\x12\x12\n\nchannel_id\x18\x01 \x01(\t\x12\x0f\n\x07relayer\x18\x02 \x01(\t\x12\x1a\n\x12\x63ounterparty_payee\x18\x03 \x01(\t\"`\n\x15\x46orwardRelayerAddress\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x36\n\tpacket_id\x18\x02 \x01(\x0b\x32\x1d.ibc.core.channel.v1.PacketIdB\x04\xc8\xde\x1f\x00\x42\x37Z5github.com/cosmos/ibc-go/v7/modules/apps/29-fee/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.fee.v1.genesis_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/cosmos/ibc-go/v7/modules/apps/29-fee/types'
  _GENESISSTATE.fields_by_name['identified_fees']._options = None
  _GENESISSTATE.fields_by_name['identified_fees']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE.fields_by_name['fee_enabled_channels']._options = None
  _GENESISSTATE.fields_by_name['fee_enabled_channels']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE.fields_by_name['registered_payees']._options = None
  _GENESISSTATE.fields_by_name['registered_payees']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE.fields_by_name['registered_counterparty_payees']._options = None
  _GENESISSTATE.fields_by_name['registered_counterparty_payees']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE.fields_by_name['forward_relayers']._options = None
  _GENESISSTATE.fields_by_name['forward_relayers']._serialized_options = b'\310\336\037\000'
  _FORWARDRELAYERADDRESS.fields_by_name['packet_id']._options = None
  _FORWARDRELAYERADDRESS.fields_by_name['packet_id']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE._serialized_start=159
  _GENESISSTATE._serialized_end=586
  _FEEENABLEDCHANNEL._serialized_start=588
  _FEEENABLEDCHANNEL._serialized_end=644
  _REGISTEREDPAYEE._serialized_start=646
  _REGISTEREDPAYEE._serialized_end=715
  _REGISTEREDCOUNTERPARTYPAYEE._serialized_start=717
  _REGISTEREDCOUNTERPARTYPAYEE._serialized_end=811
  _FORWARDRELAYERADDRESS._serialized_start=813
  _FORWARDRELAYERADDRESS._serialized_end=909
# @@protoc_insertion_point(module_scope)
